quickref
Date: 2012-12-26T17:14:58+00:00

Chapter 1

Keyboard and Mouse Quick Reference

1.1

Main image window

These keyboard and mouse operations are available when the main image window has the focus.

1.1.1

Panning and Zooming commands

Scroll wheel turned

Zoom in or out

Digit (1234567890)

Zoom image to 1X, 2X, ..., 9X, 10X

Shift + Digit

Zoom image to 1/2X, 1/3X, ..., 1/9X, 1/10X

Backquote (`)

Zoom image to fit window

Minus, Underscore (- )

Zoom out

Equals, Plus (=+)

Zoom in

Middle (scroll) button drag

Pan image freely (when zoomed in)

p

Set pan position for zooming

Shift + Left click

Set pan position for zooming

q

Pan image freely (when zoomed in); move mouse (no button press);
left click to terminate)

Ctrl + Left drag

Proportional pan (press and drag left mouse button)

apostrophe (')

Set autozoom for new images to override

doublequote ('')

Set autozoom for new images to on

1.1.2

Cut levels and colormap commands

a

Auto cut levels

comma, left angle (,>)

Interactive cut low (with left mouse button)

period, right angle (.<)

Interactive cut high (with left mouse button)

slash (/)

Interactive shift colormap (with left mouse button)

semicolon (;)

Set autocuts for new images to override

colon (:)

Set autocuts for new images to on

Ctrl + Scroll wheel turned

Adjust both high and low cut levels (coarse adjustment)

Shift + Scroll wheel turned

Adjust both high and low cut levels (fine adjustment)

1

1.1. MAIN IMAGE WINDOW

—Draft—

Ginga FITS Viewer Manual

1.1.3

Transform commands

Left bracket ([)

Flip image in X

Left brace (

{)

Restore image in X

Right bracket (])

Flip image in Y

Right brace (

})

Restore image in Y

Backslash (

\)

Swap X and Y axes

Vertical bar (

|)

Restore X and Y axes

r

Interactive rotate (with left mouse button)

R

Restore rotation to 0 degrees

1.1.4

Tab Navigation

I

Raise Info tab

H

Raise Header tab

Z

Raise Zoom tab

D

Raise Dialogs tab

T

Raise Thumbs tab

C

Raise Contents tab

?

Raise Help tab

1.1.5

Plugins

Escape

Stop current plugin operation

F1

Start Pick

Stellar evaluation

F2

Start Ruler

Measure distances

F3

(Reserved for future use)

F4

Start MultiDim

Browse HDUs and image slices

F5

Start Cuts

Graph pixel values along a line

F6

Start Histogram

Graph pixel values in a region

F7

Start PixTable

Show maxtrix of pixel values around cursor

F8

(Reserved for future use)

F9

Start Preferences

Set preferences for a channel

F10

Start Catalog

Access image and star catalogs

F11

Start Drawing

Draw graphics on an image

F12

Start FBrowser

Browse and load files

If there are one or more plugins active, additional mouse or keyboard bindings may be present. In
general, the left mouse button is used to select, pick or move, and the right mouse button is used to
draw a shape for the operation. On the Mac, control + mouse button can also be used to draw or
right click.

2